==> ksteak-0.4.3.tar.gz: ksteak-0.4.3/ksteak/dockwidget.cpp <==
/***************************************************************************
                          dockwidget.cpp  -  description
                             -------------------
    begin                : Fri Nov 14 2000
    copyright            : (C) 2000 by Michael Heidecke
    email                : heidecke@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dockwidget.h"
#include <kapp.h>
#include <klocale.h>
#include <kiconloader.h>
#include <qcursor.h>
#include <qclipboard.h>
#include <stdio.h>
//#include <iostream.h>

/*************************************************
 * create dockwidget with popup-menu             *
 *************************************************/
dockwidget::dockwidget(QWidget *, const char * name) : KSystemTray(0, name)
{
//  myview = 0;
//  mypop = 0;


  //create Popup-window
  mypop = new KPopupFrame(this);
  //we dont need decorations
  mypop->setFrameStyle(QFrame::Box | QFrame::Plain);
  mypop->setLineWidth(2); //black frame
  // TextView
  myview = new QTextView(mypop);
  myview->setFrameStyle(QFrame::NoFrame);

  popup_menu = new KPopupMenu(this);
  popup_menu->setTitle("KSteak");
  popup_menu->insertItem(i18n("Undock"), 1);
  popup_menu->insertSeparator();
  popup_menu->insertItem(SmallIcon("configure"), i18n("Configure KSteak"), 2);
  popup_menu->insertSeparator();
  popup_menu->insertItem(SmallIcon("exit.png"), i18n("Quit"), 3);
  connect(popup_menu, SIGNAL(activated(int)), this, SLOT(slotMenuClicked(int)));
}

/*************************************************
 * destructor                                    *
 *************************************************/
dockwidget::~dockwidget()
{
  delete popup_menu;
  delete mypop;
  delete myview;
}

/*************************************************
 * exec popup-menu on mousepressevent            *
 *************************************************/
void dockwidget::mousePressEvent(QMouseEvent* e)
{
  if (e->button() == RightButton) popup_menu->exec(QCursor::pos());
  if (e->button() == LeftButton)
  {
  	if (myview->hasSelectedText())
  		getTranslation( myview->selectedText() );
	else
		getTranslation( kapp->clipboard()->text() );

	//getTranslation("");
  }
}

/*************************************************
 * emit signals when (un-)dock                   *
 *************************************************/
void dockwidget::slotMenuClicked(int i)
{
  if (i == 1) emit undock();
  if (i == 2) emit configure();
  if (i == 3) emit done();
}

void dockwidget::getTranslation(const QString & szWord)
{
  int x = QCursor::pos().x();
  int y = QCursor::pos().y();

/*
  if (myview) delete myview;
  if (mypop) delete mypop;

  //create Popup-window
  mypop = new KPopupFrame(this);
  //we dont need decorations
  mypop->setFrameStyle(QFrame::Box | QFrame::Plain);
  mypop->setLineWidth(2); //black frame
  // TextView
  myview = new QTextView(mypop);
  myview->setFrameStyle(QFrame::NoFrame);
*/
  emit translate( szWord );

  int w = myview->width();
  int h = myview->height();

  //clever placement
  if (x-w < 1) w = 0;
  if (y-h < 1) h = 0;

  mypop->setMainWidget( myview );
  mypop->popup( QPoint(x-w, y-h) );
}

==> ksteak-0.9.0.tar.gz: ksteak-0.9.0/ksteak/dockwidget.cpp <==
/***************************************************************************
                          dockwidget.cpp  -  description
                             -------------------
    begin                : Fri Nov 14 2000
    copyright            : (C) 2000 by Michael Heidecke
    email                : heidecke@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "dockwidget.h"
#include <kapp.h>
#include <klocale.h>
#include <kiconloader.h>
#include <qcursor.h>
#include <qclipboard.h>
#include <stdio.h>
//#include <iostream.h>

/*************************************************
 * create dockwidget with popup-menu             *
 *************************************************/
dockwidget::dockwidget(QWidget *, const char * name) : KSystemTray(0, name)
{
//  myview = 0;
//  mypop = 0;


  //create Popup-window
  mypop = new KPopupFrame(this);
  //we dont need decorations
  mypop->setFrameStyle(QFrame::Box | QFrame::Plain);
  mypop->setLineWidth(2); //black frame
  // TextView
  myview = new QTextView(mypop);
  myview->setFrameStyle(QFrame::NoFrame);

  popup_menu = new KPopupMenu(this);
  popup_menu->setTitle("KSteak");
  popup_menu->insertItem(SmallIcon("top"), i18n("Undock"), 1);
  popup_menu->insertSeparator();
  popup_menu->insertItem(SmallIcon("configure"), i18n("Configure KSteak"), 2);
  popup_menu->insertSeparator();
  popup_menu->insertItem(SmallIcon("viewmag"), i18n("Toggle Watching"), 4);
  popup_menu->insertSeparator();
  popup_menu->insertItem(SmallIcon("exit"), i18n("Quit"), 3);
  connect(popup_menu, SIGNAL(activated(int)), this, SLOT(slotMenuClicked(int)));
}

/*************************************************
 * destructor                                    *
 *************************************************/
dockwidget::~dockwidget()
{
  delete popup_menu;
  delete mypop;
  delete myview;
}

/*************************************************
 * exec popup-menu on mousepressevent            *
 *************************************************/
void dockwidget::mousePressEvent(QMouseEvent* e)
{
  if (e->button() == RightButton) popup_menu->exec(QCursor::pos());
  if (e->button() == MidButton) emit toggleWatchCb();
  if (e->button() == LeftButton)
  {
  	if (myview->hasSelectedText())
  		getTranslation( myview->selectedText() );
	else
		getTranslation( kapp->clipboard()->text() );

	//getTranslation("");
  }
}

/*************************************************
 * emit signals when (un-)dock                   *
 *************************************************/
void dockwidget::slotMenuClicked(int i)
{
  if (i == 1) emit undock();
  if (i == 2) emit configure();
  if (i == 3) emit done();
  if (i == 4) emit toggleWatchCb();
}

void dockwidget::getTranslation(const QString & szWord)
{
	int x, y;

	if (_fPopup)
	{
		QPoint mpos = mapToGlobal(QPoint(this->x(), this->y()));
		x = mpos.x();
		y = mpos.y();
	}
	else
	{
		x = QCursor::pos().x();
		y = QCursor::pos().y();
	}
/*
  if (myview) delete myview;
  if (mypop) delete mypop;

  //create Popup-window
  mypop = new KPopupFrame(this);
  //we dont need decorations
  mypop->setFrameStyle(QFrame::Box | QFrame::Plain);
  mypop->setLineWidth(2); //black frame
  // TextView
  myview = new QTextView(mypop);
  myview->setFrameStyle(QFrame::NoFrame);
*/
  emit translate( szWord );

  int w = myview->width();
  int h = myview->height();

  //clever placement
  if (x-w < 1) w = 0;
  if (y-h < 1) h = 0;

  mypop->setMainWidget( myview );
  mypop->popup( QPoint(x-w, y-h) );
}
